@@ -37,6 +37,9 @@ sub new {
 		Wx::wxTE_CENTRE,
 	);
 	$self->{m_textCtrl1}->SetMaxLength( 50 );
+	$self->{m_textCtrl1}->SetBackgroundColour(
+		Wx::Colour->new(255, 128, 0)
+	);
 
 	$self->{m_button1} = Wx::Button->new(
 		$self,
@@ -68,6 +71,7 @@ sub new {
 		Wx::wxDefaultSize,
 		Wx::wxSP_3D,
 	);
+	$self->{m_splitter1}->SetSashGravity(0.5);
 	$self->{m_splitter1}->SetMinimumPaneSize(50);
 
 	$self->{m_panel3} = Wx::Panel->new(
@@ -210,6 +214,21 @@ sub new {
 		-1,
 		Wx::gettext("This is a test"),
 	);
+	$self->{m_staticText2}->SetForegroundColour(
+		Wx::Colour->new(0, 0, 255)
+	);
+
+	$self->{m_spinCtrl1} = Wx::SpinCtrl->new(
+		$self->{m_panel1},
+		-1,
+		"",
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxSP_ARROW_KEYS,
+		0,
+		10,
+		5,
+	);
 
 	$self->{m_panel2} = Wx::Panel->new(
 		$self->{m_listbook1},
@@ -227,6 +246,55 @@ sub new {
 		Wx::wxDefaultSize,
 	);
 
+	$self->{m_colourPicker1} = Wx::ColourPickerCtrl->new(
+		$self->{m_panel2},
+		-1,
+		Wx::Colour->new(255, 0, 0),
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxCLRP_DEFAULT_STYLE,
+	);
+
+	$self->{m_colourPicker2} = Wx::ColourPickerCtrl->new(
+		$self->{m_panel2},
+		-1,
+		Wx::SystemSettings::GetColour( Wx::wxSYS_COLOUR_INFOBK ),
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxCLRP_DEFAULT_STYLE,
+	);
+
+	$self->{m_fontPicker1} = Wx::FontPickerCtrl->new(
+		$self->{m_panel2},
+		-1,
+		Wx::wxNullFont,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxFNTP_DEFAULT_STYLE,
+	);
+	$self->{m_fontPicker1}->SetMaxPointSize(100);
+
+	$self->{m_filePicker1} = Wx::FilePickerCtrl->new(
+		$self->{m_panel2},
+		-1,
+		"",
+		"Select a file",
+		"*.*",
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxFLP_DEFAULT_STYLE,
+	);
+
+	$self->{m_dirPicker1} = Wx::DirPickerCtrl->new(
+		$self->{m_panel2},
+		-1,
+		"",
+		"Select a folder",
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxDIRP_DEFAULT_STYLE,
+	);
+
 	my $fgSizer1 = Wx::FlexGridSizer->new( 1, 2, 3, 4 );
 	$fgSizer1->AddGrowableCol( 0 );
 	$fgSizer1->AddGrowableCol( 1 );
@@ -266,6 +334,26 @@ sub new {
 	$gSizer1->Add( $self->{m_checkBox3}, 0, Wx::wxALL, 5 );
 	$gSizer1->Add( $self->{m_checkBox4}, 0, Wx::wxALL, 5 );
 
+	my $bSizer3 = Wx::BoxSizer->new( Wx::wxVERTICAL );
+	$bSizer3->Add( $self->{m_staticText2}, 0, Wx::wxALL, 5 );
+	$bSizer3->Add( $self->{m_spinCtrl1}, 0, Wx::wxALL, 5 );
+
+	$self->{m_panel1}->SetSizer($bSizer3);
+	$self->{m_panel1}->Layout;
+	$bSizer3->Fit($self->{m_panel1});
+
+	my $bSizer4 = Wx::BoxSizer->new( Wx::wxVERTICAL );
+	$bSizer4->Add( $self->{m_textCtrl2}, 0, Wx::wxALL, 5 );
+	$bSizer4->Add( $self->{m_colourPicker1}, 0, Wx::wxALL, 5 );
+	$bSizer4->Add( $self->{m_colourPicker2}, 0, Wx::wxALL, 5 );
+	$bSizer4->Add( $self->{m_fontPicker1}, 0, Wx::wxALL, 5 );
+	$bSizer4->Add( $self->{m_filePicker1}, 0, Wx::wxALL, 5 );
+	$bSizer4->Add( $self->{m_dirPicker1}, 0, Wx::wxALL, 5 );
+
+	$self->{m_panel2}->SetSizer($bSizer4);
+	$self->{m_panel2}->Layout;
+	$bSizer4->Fit($self->{m_panel2});
+
 	$self->{m_listbook1}->AddPage( $self->{m_panel1}, Wx::gettext("Page One"), 1 );
 	$self->{m_listbook1}->AddPage( $self->{m_panel2}, Wx::gettext("Page Two"), 0 );
 
